Package: plyinteractions
Title: Extending tidy verbs to genomic interactions
Description: Operate on `GInteractions` objects as tabular data using 
    `dplyr`-like verbs. The functions and methods in `plyinteractions`
    provide a grammatical approach to manipulate `GInteractions`, to 
    facilitate their integration in genomic analysis workflows. 
Version: 1.10.0
Date: 2026-01-07
Authors@R: 
    c(person("Jacques", "Serizay", , "jacquesserizay@gmail.com",
        role = c("aut", "cre")
    ))
License: Artistic-2.0
URL: https://github.com/js2264/plyinteractions
BugReports: https://github.com/js2264/plyinteractions/issues
biocViews: Software, Infrastructure
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Depends: R (>= 4.3.0), InteractionSet, plyranges
Imports: Seqinfo, BiocGenerics, GenomicRanges, IRanges, S4Vectors,
        rlang, dplyr, tibble, tidyselect, methods, utils
Suggests: tidyverse, BSgenome.Mmusculus.UCSC.mm10, Biostrings,
        BiocParallel, GenomeInfoDb, scales, HiContactsData,
        rtracklayer, BiocStyle, covr, knitr, rmarkdown, sessioninfo,
        testthat (>= 3.0.0), RefManageR
Config/testthat/edition: 3
VignetteBuilder: knitr
RoxygenNote: 7.3.3
Collate: 'attach.R' 'zzz.R' 'AllGenerics.R' 'AllClasses.R'
        'add_pairdist.R' 'anchor.R' 'annotate.R' 'arrange.R'
        'count-overlaps.R' 'count.R' 'data.R' 'export.R'
        'filter-overlaps.R' 'filter.R' 'find-overlaps.R' 'flank.R'
        'ginteractions-construct.R' 'ginteractions-env.R'
        'ginteractions-getters.R' 'ginteractions-scoping.R'
        'ginteractions-setters.R' 'tbl_vars.R' 'group_data.R'
        'group_by.R' 'internals.R' 'join-overlap-left.R'
        'methods-AnchoredPinnedGInteractions.R'
        'methods-DelegatingGInteractions.R'
        'methods-GroupedGInteractions.R'
        'methods-PinnedGInteractions.R' 'methods-show.R' 'mutate.R'
        'pair-granges.R' 'pin.R' 'plyinteractions.R' 'rename.R'
        'replace-anchors.R' 'select.R' 'shift.R' 'slice.R' 'stretch.R'
        'summarize.R'
LazyData: false
git_url: https://git.bioconductor.org/packages/plyinteractions
git_branch: RELEASE_3_23
git_last_commit: b2ae5fd
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:09:34 UTC; biocbuild
Author: Jacques Serizay [aut, cre]
Maintainer: Jacques Serizay <jacquesserizay@gmail.com>
Built: R 4.6.0; ; 2026-04-29 04:54:49 UTC; unix
