# Generated by roxygen2: do not edit by hand

S3method(anchor,AnchoredPinnedGInteractions)
S3method(anchor_3p,AnchoredPinnedGInteractions)
S3method(anchor_3p,PinnedGInteractions)
S3method(anchor_5p,AnchoredPinnedGInteractions)
S3method(anchor_5p,PinnedGInteractions)
S3method(anchor_center,AnchoredPinnedGInteractions)
S3method(anchor_center,PinnedGInteractions)
S3method(anchor_end,AnchoredPinnedGInteractions)
S3method(anchor_end,PinnedGInteractions)
S3method(anchor_start,AnchoredPinnedGInteractions)
S3method(anchor_start,PinnedGInteractions)
S3method(arrange,GInteractions)
S3method(as_ginteractions,data.frame)
S3method(as_ginteractions,default)
S3method(count,GInteractions)
S3method(count,GroupedGInteractions)
S3method(count_overlaps,GInteractions)
S3method(count_overlaps,PinnedGInteractions)
S3method(count_overlaps_directed,GInteractions)
S3method(count_overlaps_directed,PinnedGInteractions)
S3method(filter,GInteractions)
S3method(filter_by_non_overlaps,GInteractions)
S3method(filter_by_non_overlaps,PinnedGInteractions)
S3method(filter_by_overlaps,GInteractions)
S3method(filter_by_overlaps,PinnedGInteractions)
S3method(find_overlaps,GInteractions)
S3method(find_overlaps,PinnedGInteractions)
S3method(find_overlaps_directed,GInteractions)
S3method(find_overlaps_directed,PinnedGInteractions)
S3method(flank_downstream,PinnedGInteractions)
S3method(flank_downstream,Ranges)
S3method(flank_left,PinnedGInteractions)
S3method(flank_left,Ranges)
S3method(flank_right,PinnedGInteractions)
S3method(flank_right,Ranges)
S3method(flank_upstream,PinnedGInteractions)
S3method(flank_upstream,Ranges)
S3method(group_by,DelegatingGInteractions)
S3method(group_by,GInteractions)
S3method(group_by,GroupedGInteractions)
S3method(group_data,GroupedGInteractions)
S3method(group_indices,GroupedGInteractions)
S3method(group_keys,GroupedGInteractions)
S3method(group_size,GroupedGInteractions)
S3method(group_vars,GInteractions)
S3method(group_vars,GroupedGInteractions)
S3method(groups,GroupedGInteractions)
S3method(join_overlap_left,GInteractions)
S3method(join_overlap_left,PinnedGInteractions)
S3method(join_overlap_left_directed,GInteractions)
S3method(join_overlap_left_directed,PinnedGInteractions)
S3method(mutate,GInteractions)
S3method(n_groups,GroupedGInteractions)
S3method(rename,GInteractions)
S3method(select,GInteractions)
S3method(shift_downstream,PinnedGInteractions)
S3method(shift_downstream,Ranges)
S3method(shift_left,PinnedGInteractions)
S3method(shift_left,Ranges)
S3method(shift_right,PinnedGInteractions)
S3method(shift_right,Ranges)
S3method(shift_upstream,PinnedGInteractions)
S3method(shift_upstream,Ranges)
S3method(slice,GInteractions)
S3method(stretch,AnchoredPinnedGInteractions)
S3method(stretch,PinnedGInteractions)
S3method(summarise,GroupedGInteractions)
S3method(summarize,GroupedGInteractions)
S3method(tally,GroupedGInteractions)
S3method(tbl_vars,GInteractions)
S3method(unanchor,AnchoredPinnedGInteractions)
S3method(ungroup,GroupedGInteractions)
export(add_pairdist)
export(anchors1)
export(anchors2)
export(annotate)
export(annotate_directed)
export(as_ginteractions)
export(end1)
export(end2)
export(flank_downstream)
export(flank_left)
export(flank_right)
export(flank_upstream)
export(pair_granges)
export(pin)
export(pin_anchors1)
export(pin_anchors2)
export(pin_by)
export(pin_first)
export(pin_second)
export(pinned_anchors)
export(ranges1)
export(ranges2)
export(replace_anchors)
export(seqnames1)
export(seqnames2)
export(shift_downstream)
export(shift_left)
export(shift_right)
export(shift_upstream)
export(start1)
export(start2)
export(strand1)
export(strand2)
export(unpin)
export(width1)
export(width2)
export(write_bedpe)
export(write_pairs)
exportMethods("$")
exportMethods(anchors1)
exportMethods(anchors2)
exportMethods(annotate)
exportMethods(annotate_directed)
exportMethods(end1)
exportMethods(end2)
exportMethods(pin)
exportMethods(pinned_anchors)
exportMethods(ranges1)
exportMethods(ranges2)
exportMethods(replace_anchors)
exportMethods(seqnames1)
exportMethods(seqnames2)
exportMethods(show)
exportMethods(start1)
exportMethods(start2)
exportMethods(strand1)
exportMethods(strand2)
exportMethods(unpin)
exportMethods(width1)
exportMethods(width2)
importFrom(BiocGenerics,end)
importFrom(BiocGenerics,start)
importFrom(BiocGenerics,strand)
importFrom(BiocGenerics,width)
importFrom(GenomicRanges,GRanges)
importFrom(GenomicRanges,granges)
importFrom(IRanges,IRanges)
importFrom(IRanges,ranges)
importFrom(IRanges,subsetByOverlaps)
importFrom(InteractionSet,GInteractions)
importFrom(InteractionSet,anchors)
importFrom(InteractionSet,countOverlaps)
importFrom(InteractionSet,findOverlaps)
importFrom(InteractionSet,regions)
importFrom(S4Vectors,"first<-")
importFrom(S4Vectors,"mcols<-")
importFrom(S4Vectors,"second<-")
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,Rle)
importFrom(S4Vectors,as.env)
importFrom(S4Vectors,cbind)
importFrom(S4Vectors,decode)
importFrom(S4Vectors,mcols)
importFrom(S4Vectors,queryHits)
importFrom(S4Vectors,queryLength)
importFrom(S4Vectors,rbind)
importFrom(S4Vectors,showAsCell)
importFrom(S4Vectors,subjectHits)
importFrom(S4Vectors,subjectLength)
importFrom(Seqinfo,seqinfo)
importFrom(Seqinfo,seqnames)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,group_data)
importFrom(dplyr,group_indices)
importFrom(dplyr,group_keys)
importFrom(dplyr,group_size)
importFrom(dplyr,group_vars)
importFrom(dplyr,groups)
importFrom(dplyr,mutate)
importFrom(dplyr,n_groups)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,tally)
importFrom(dplyr,tbl_vars)
importFrom(dplyr,ungroup)
importFrom(methods,as)
importFrom(methods,getGeneric)
importFrom(methods,getGenerics)
importFrom(methods,initialize)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,prototype)
importFrom(methods,representation)
importFrom(methods,selectMethod)
importFrom(methods,setMethod)
importFrom(methods,show)
importFrom(methods,validObject)
importFrom(plyranges,anchor)
importFrom(plyranges,anchor_3p)
importFrom(plyranges,anchor_5p)
importFrom(plyranges,anchor_center)
importFrom(plyranges,anchor_end)
importFrom(plyranges,anchor_start)
importFrom(plyranges,count_overlaps)
importFrom(plyranges,count_overlaps_directed)
importFrom(plyranges,filter_by_non_overlaps)
importFrom(plyranges,filter_by_overlaps)
importFrom(plyranges,find_overlaps)
importFrom(plyranges,find_overlaps_directed)
importFrom(plyranges,flank_downstream)
importFrom(plyranges,flank_left)
importFrom(plyranges,flank_right)
importFrom(plyranges,flank_upstream)
importFrom(plyranges,join_overlap_left)
importFrom(plyranges,join_overlap_left_directed)
importFrom(plyranges,set_width)
importFrom(plyranges,shift_downstream)
importFrom(plyranges,shift_left)
importFrom(plyranges,shift_right)
importFrom(plyranges,shift_upstream)
importFrom(plyranges,stretch)
importFrom(plyranges,unanchor)
importFrom(rlang,"!!!")
importFrom(rlang,`:=`)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr)
importFrom(rlang,inform)
importFrom(rlang,is_call)
importFrom(rlang,local_options)
importFrom(rlang,quo)
importFrom(rlang,quo_get_expr)
importFrom(rlang,quo_is_null)
importFrom(rlang,quo_name)
importFrom(rlang,quos)
importFrom(rlang,set_names)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(rlang,warn)
importFrom(tibble,as_tibble)
importFrom(tidyselect,eval_rename)
importFrom(tidyselect,eval_select)
importFrom(utils,.DollarNames)
importFrom(utils,capture.output)
