#' @rdname reexports
#' @importFrom plyranges as_granges
#' @importFrom plyranges anchor
#' @export
plyranges::anchor

#' @rdname reexports
#' @importFrom plyranges unanchor
#' @export
plyranges::unanchor

#' @rdname reexports
#' @importFrom plyranges anchor_start
#' @export
plyranges::anchor_start

#' @rdname reexports
#' @importFrom plyranges anchor_end
#' @export
plyranges::anchor_end

#' @rdname reexports
#' @importFrom plyranges anchor_center
#' @export
plyranges::anchor_center

#' @rdname reexports
#' @importFrom plyranges anchor_3p
#' @export
plyranges::anchor_3p

#' @rdname reexports
#' @importFrom plyranges anchor_5p
#' @export
plyranges::anchor_5p

#' @rdname reexports
#' @importFrom plyranges stretch
#' @export
plyranges::stretch

#' @rdname reexports
#' @importFrom plyranges find_overlaps
#' @export
plyranges::find_overlaps

#' @rdname reexports
#' @importFrom plyranges find_overlaps_directed
#' @export
plyranges::find_overlaps_directed

#' @rdname reexports
#' @importFrom plyranges count_overlaps
#' @export
plyranges::count_overlaps

#' @rdname reexports
#' @importFrom plyranges count_overlaps_directed
#' @export
plyranges::count_overlaps_directed

#' @rdname reexports
#' @importFrom plyranges filter_by_overlaps
#' @export
plyranges::filter_by_overlaps

#' @rdname reexports
#' @importFrom plyranges filter_by_non_overlaps
#' @export
plyranges::filter_by_non_overlaps

#' @rdname reexports
#' @importFrom plyranges join_overlap_left
#' @export
plyranges::join_overlap_left

#' @rdname reexports
#' @importFrom plyranges join_overlap_left_directed
#' @export
plyranges::join_overlap_left_directed
