#' @rdname reexports
#' @importFrom dplyr mutate
#' @export
dplyr::mutate

#' @rdname reexports
#' @importFrom dplyr slice
#' @export
dplyr::slice

#' @rdname reexports
#' @importFrom dplyr select
#' @export
dplyr::select

#' @rdname reexports
#' @importFrom dplyr filter
#' @export
dplyr::filter

#' @rdname reexports
#' @importFrom dplyr arrange
#' @export
dplyr::arrange

#' @rdname reexports
#' @importFrom dplyr rename
#' @export
dplyr::rename

#' @rdname reexports
#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @rdname reexports
#' @importFrom dplyr group_data
#' @export
dplyr::group_data

#' @rdname reexports
#' @importFrom dplyr group_keys
#' @export
dplyr::group_keys

#' @rdname reexports
#' @importFrom dplyr group_indices
#' @export
dplyr::group_indices

#' @rdname reexports
#' @importFrom dplyr group_vars
#' @export
dplyr::group_vars

#' @rdname reexports
#' @importFrom dplyr groups
#' @export
dplyr::groups

#' @rdname reexports
#' @importFrom dplyr group_size
#' @export
dplyr::group_size

#' @rdname reexports
#' @importFrom dplyr n_groups
#' @export
dplyr::n_groups

#' @rdname reexports
#' @importFrom dplyr group_rows
#' @export
dplyr::group_rows

#' @rdname reexports
#' @importFrom dplyr ungroup
#' @export
dplyr::ungroup

#' @rdname reexports
#' @importFrom dplyr summarize
#' @export
dplyr::summarize

#' @rdname reexports
#' @importFrom dplyr summarise
#' @export
dplyr::summarise

#' @rdname reexports
#' @importFrom dplyr tally
#' @export
dplyr::tally

#' @rdname reexports
#' @importFrom dplyr count
#' @export
dplyr::count
